@@ -1,10 +1,10 @@
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
 __git_branch__ = '(Not currently on any branch)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = 'b85a03cf24197f375f848cb083cca516f14decfb'
-__git_head_subject__ = 'empty commit after version v0.1'
+__git_head_hash__ = '6c9960e233a54e32ce43f6376bf73c303afa4251'
+__git_head_subject__ = 'Finished release v0.1.2.'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
